Redirect Rest API — Rucio 1.2 documentation

# Redirect Rest API

Overview

Resource | Operation | Description
--- | --- | ---
HeaderRedirector | GET /redirect/(scope)/(name) | Header redirect.
MetaLinkRedirector | GET /redirect/(scope)/(name)/metalink | Metalink redirect.

Details

`GET` `/redirect/`(scope)`/`(name)`/metalink`

  Metalink redirect

  HTTP Success:
    200 OK
  HTTP Error:
    401 Unauthorized 500 InternalError 404 Notfound

  Parameters: | scope – The scope name of the file. name – The name of the file.
  Response Headers:
  | Content-Type – application/metalink4+xml’.
  Status Codes: | 200 OK – OK. 401 Unauthorized – Invalid Auth Token. 404 Not Found – RSE Not Found. 404 Not Found – DID Not Found. 500 Internal Server Error – Internal Error.
  Returns: | Metalink file

`GET` `/redirect/`(scope)`/`(name)

  Header Redirect

  Parameters: | scope – The scope name of the file. name – The name of the file.
  Response Headers:
  | Content-Type – application/metalink+xml’.
  Status Codes: | 303 See Other – Redirect. 401 Unauthorized – Invalid Auth Token. 404 Not Found – RSE Not Found. 404 Not Found – DID Not Found. 500 Internal Server Error – Internal Error.